@@ -1,25 +1,26 @@
 /*
-@ @licstart  The following is the entire license notice for the
-JavaScript code in this file.
+ @licstart  The following is the entire license notice for the JavaScript code in this file.
 
-Copyright (C) 1997-2017 by Dimitri van Heesch
+ The MIT License (MIT)
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
+ Copyright (C) 1997-2020 by Dimitri van Heesch
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
+ Permission is hereby granted, free of charge, to any person obtaining a copy of this software
+ and associated documentation files (the "Software"), to deal in the Software without restriction,
+ including without limitation the rights to use, copy, modify, merge, publish, distribute,
+ sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
+ furnished to do so, subject to the following conditions:
 
-You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ The above copyright notice and this permission notice shall be included in all copies or
+ substantial portions of the Software.
 
-@licend  The above is the entire license notice
-for the JavaScript code in this file
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
+ BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+ DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+ @licend  The above is the entire license notice for the JavaScript code in this file
 */
 var menudata={children:[
 {text:"Main Page",url:"index.html"},
@@ -37,6 +38,7 @@ var menudata={children:[
 {text:"g",url:"namespacemembers_g.html#index_g"},
 {text:"h",url:"namespacemembers_h.html#index_h"},
 {text:"i",url:"namespacemembers_i.html#index_i"},
+{text:"k",url:"namespacemembers_k.html#index_k"},
 {text:"l",url:"namespacemembers_l.html#index_l"},
 {text:"m",url:"namespacemembers_m.html#index_m"},
 {text:"n",url:"namespacemembers_n.html#index_n"},
@@ -62,6 +64,7 @@ var menudata={children:[
 {text:"g",url:"namespacemembers_func_g.html#index_g"},
 {text:"h",url:"namespacemembers_func_h.html#index_h"},
 {text:"i",url:"namespacemembers_func_i.html#index_i"},
+{text:"k",url:"namespacemembers_func_k.html#index_k"},
 {text:"l",url:"namespacemembers_func_l.html#index_l"},
 {text:"m",url:"namespacemembers_func_m.html#index_m"},
 {text:"n",url:"namespacemembers_func_n.html#index_n"},
@@ -78,54 +81,57 @@ var menudata={children:[
 {text:"Variables",url:"namespacemembers_vars.html"},
 {text:"Typedefs",url:"namespacemembers_type.html",children:[
 {text:"a",url:"namespacemembers_type.html#index_a"},
-{text:"b",url:"namespacemembers_type.html#index_b"},
-{text:"d",url:"namespacemembers_type.html#index_d"},
-{text:"f",url:"namespacemembers_type.html#index_f"},
-{text:"g",url:"namespacemembers_type.html#index_g"},
-{text:"i",url:"namespacemembers_type.html#index_i"},
-{text:"l",url:"namespacemembers_type.html#index_l"},
-{text:"m",url:"namespacemembers_type.html#index_m"},
-{text:"n",url:"namespacemembers_type.html#index_n"},
-{text:"p",url:"namespacemembers_type.html#index_p"},
-{text:"q",url:"namespacemembers_type.html#index_q"},
-{text:"r",url:"namespacemembers_type.html#index_r"},
-{text:"s",url:"namespacemembers_type.html#index_s"},
-{text:"t",url:"namespacemembers_type.html#index_t"},
-{text:"u",url:"namespacemembers_type.html#index_u"},
-{text:"v",url:"namespacemembers_type.html#index_v"},
-{text:"w",url:"namespacemembers_type.html#index_w"}]},
+{text:"b",url:"namespacemembers_type_b.html#index_b"},
+{text:"c",url:"namespacemembers_type_c.html#index_c"},
+{text:"d",url:"namespacemembers_type_d.html#index_d"},
+{text:"f",url:"namespacemembers_type_f.html#index_f"},
+{text:"g",url:"namespacemembers_type_g.html#index_g"},
+{text:"i",url:"namespacemembers_type_i.html#index_i"},
+{text:"l",url:"namespacemembers_type_l.html#index_l"},
+{text:"m",url:"namespacemembers_type_m.html#index_m"},
+{text:"n",url:"namespacemembers_type_n.html#index_n"},
+{text:"o",url:"namespacemembers_type_o.html#index_o"},
+{text:"p",url:"namespacemembers_type_p.html#index_p"},
+{text:"q",url:"namespacemembers_type_q.html#index_q"},
+{text:"r",url:"namespacemembers_type_r.html#index_r"},
+{text:"s",url:"namespacemembers_type_s.html#index_s"},
+{text:"t",url:"namespacemembers_type_t.html#index_t"},
+{text:"u",url:"namespacemembers_type_u.html#index_u"},
+{text:"v",url:"namespacemembers_type_v.html#index_v"},
+{text:"w",url:"namespacemembers_type_w.html#index_w"}]},
 {text:"Enumerations",url:"namespacemembers_enum.html"},
 {text:"Enumerator",url:"namespacemembers_eval.html",children:[
 {text:"a",url:"namespacemembers_eval.html#index_a"},
-{text:"b",url:"namespacemembers_eval.html#index_b"},
-{text:"c",url:"namespacemembers_eval.html#index_c"},
-{text:"d",url:"namespacemembers_eval.html#index_d"},
-{text:"e",url:"namespacemembers_eval.html#index_e"},
-{text:"f",url:"namespacemembers_eval.html#index_f"},
-{text:"g",url:"namespacemembers_eval.html#index_g"},
-{text:"h",url:"namespacemembers_eval.html#index_h"},
-{text:"i",url:"namespacemembers_eval.html#index_i"},
-{text:"l",url:"namespacemembers_eval.html#index_l"},
-{text:"m",url:"namespacemembers_eval.html#index_m"},
-{text:"n",url:"namespacemembers_eval.html#index_n"},
-{text:"o",url:"namespacemembers_eval.html#index_o"},
-{text:"p",url:"namespacemembers_eval.html#index_p"},
-{text:"r",url:"namespacemembers_eval.html#index_r"},
-{text:"s",url:"namespacemembers_eval.html#index_s"},
-{text:"t",url:"namespacemembers_eval.html#index_t"},
-{text:"u",url:"namespacemembers_eval.html#index_u"},
-{text:"v",url:"namespacemembers_eval.html#index_v"},
-{text:"w",url:"namespacemembers_eval.html#index_w"},
-{text:"x",url:"namespacemembers_eval.html#index_x"},
-{text:"y",url:"namespacemembers_eval.html#index_y"},
-{text:"z",url:"namespacemembers_eval.html#index_z"}]}]}]},
+{text:"b",url:"namespacemembers_eval_b.html#index_b"},
+{text:"c",url:"namespacemembers_eval_c.html#index_c"},
+{text:"d",url:"namespacemembers_eval_d.html#index_d"},
+{text:"e",url:"namespacemembers_eval_e.html#index_e"},
+{text:"f",url:"namespacemembers_eval_f.html#index_f"},
+{text:"g",url:"namespacemembers_eval_g.html#index_g"},
+{text:"h",url:"namespacemembers_eval_h.html#index_h"},
+{text:"i",url:"namespacemembers_eval_i.html#index_i"},
+{text:"l",url:"namespacemembers_eval_l.html#index_l"},
+{text:"m",url:"namespacemembers_eval_m.html#index_m"},
+{text:"n",url:"namespacemembers_eval_n.html#index_n"},
+{text:"o",url:"namespacemembers_eval_o.html#index_o"},
+{text:"p",url:"namespacemembers_eval_p.html#index_p"},
+{text:"q",url:"namespacemembers_eval_q.html#index_q"},
+{text:"r",url:"namespacemembers_eval_r.html#index_r"},
+{text:"s",url:"namespacemembers_eval_s.html#index_s"},
+{text:"t",url:"namespacemembers_eval_t.html#index_t"},
+{text:"u",url:"namespacemembers_eval_u.html#index_u"},
+{text:"v",url:"namespacemembers_eval_v.html#index_v"},
+{text:"w",url:"namespacemembers_eval_w.html#index_w"},
+{text:"x",url:"namespacemembers_eval_x.html#index_x"},
+{text:"y",url:"namespacemembers_eval_y.html#index_y"},
+{text:"z",url:"namespacemembers_eval_z.html#index_z"}]}]}]},
 {text:"Classes",url:"annotated.html",children:[
 {text:"Class List",url:"annotated.html"},
 {text:"Class Hierarchy",url:"hierarchy.html"},
 {text:"Class Members",url:"functions.html",children:[
 {text:"All",url:"functions.html",children:[
-{text:":",url:"functions.html#index_0x3a"},
-{text:"_",url:"functions__.html#index__"},
+{text:":",url:"functions.html#index_:"},
+{text:"_",url:"functions__.html#index__5F"},
 {text:"a",url:"functions_a.html#index_a"},
 {text:"b",url:"functions_b.html#index_b"},
 {text:"c",url:"functions_c.html#index_c"},
@@ -152,7 +158,7 @@ var menudata={children:[
 {text:"x",url:"functions_x.html#index_x"},
 {text:"y",url:"functions_y.html#index_y"},
 {text:"z",url:"functions_z.html#index_z"},
-{text:"~",url:"functions_0x7e.html#index_0x7e"}]},
+{text:"~",url:"functions_~.html#index__7E"}]},
 {text:"Functions",url:"functions_func.html",children:[
 {text:"a",url:"functions_func.html#index_a"},
 {text:"b",url:"functions_func_b.html#index_b"},
@@ -180,12 +186,13 @@ var menudata={children:[
 {text:"x",url:"functions_func_x.html#index_x"},
 {text:"y",url:"functions_func_y.html#index_y"},
 {text:"z",url:"functions_func_z.html#index_z"},
-{text:"~",url:"functions_func_0x7e.html#index_0x7e"}]},
+{text:"~",url:"functions_func_~.html#index__7E"}]},
 {text:"Variables",url:"functions_vars.html",children:[
 {text:"a",url:"functions_vars.html#index_a"},
 {text:"b",url:"functions_vars_b.html#index_b"},
 {text:"c",url:"functions_vars_c.html#index_c"},
 {text:"d",url:"functions_vars_d.html#index_d"},
+{text:"e",url:"functions_vars_e.html#index_e"},
 {text:"f",url:"functions_vars_f.html#index_f"},
 {text:"g",url:"functions_vars_g.html#index_g"},
 {text:"h",url:"functions_vars_h.html#index_h"},
@@ -204,7 +211,7 @@ var menudata={children:[
 {text:"y",url:"functions_vars_y.html#index_y"},
 {text:"z",url:"functions_vars_z.html#index_z"}]},
 {text:"Typedefs",url:"functions_type.html",children:[
-{text:"_",url:"functions_type.html#index__"},
+{text:"_",url:"functions_type.html#index__5F"},
 {text:"a",url:"functions_type_a.html#index_a"},
 {text:"b",url:"functions_type_b.html#index_b"},
 {text:"c",url:"functions_type_c.html#index_c"},
@@ -231,13 +238,18 @@ var menudata={children:[
 {text:"Enumerations",url:"functions_enum.html"},
 {text:"Enumerator",url:"functions_eval.html",children:[
 {text:"a",url:"functions_eval.html#index_a"},
+{text:"b",url:"functions_eval.html#index_b"},
 {text:"c",url:"functions_eval.html#index_c"},
+{text:"d",url:"functions_eval.html#index_d"},
+{text:"e",url:"functions_eval.html#index_e"},
 {text:"f",url:"functions_eval.html#index_f"},
 {text:"h",url:"functions_eval.html#index_h"},
 {text:"i",url:"functions_eval.html#index_i"},
+{text:"k",url:"functions_eval.html#index_k"},
 {text:"l",url:"functions_eval.html#index_l"},
-{text:"o",url:"functions_eval.html#index_o"},
+{text:"n",url:"functions_eval.html#index_n"},
 {text:"p",url:"functions_eval.html#index_p"},
+{text:"r",url:"functions_eval.html#index_r"},
 {text:"s",url:"functions_eval.html#index_s"},
 {text:"t",url:"functions_eval.html#index_t"},
 {text:"u",url:"functions_eval.html#index_u"},
@@ -247,7 +259,7 @@ var menudata={children:[
 {text:"y",url:"functions_eval.html#index_y"},
 {text:"z",url:"functions_eval.html#index_z"}]},
 {text:"Related Functions",url:"functions_rela.html",children:[
-{text:":",url:"functions_rela.html#index_0x3a"},
+{text:":",url:"functions_rela.html#index_:"},
 {text:"a",url:"functions_rela.html#index_a"},
 {text:"b",url:"functions_rela.html#index_b"},
 {text:"c",url:"functions_rela.html#index_c"},
@@ -265,16 +277,58 @@ var menudata={children:[
 {text:"File List",url:"files.html"},
 {text:"File Members",url:"globals.html",children:[
 {text:"All",url:"globals.html",children:[
+{text:"a",url:"globals.html#index_a"},
+{text:"b",url:"globals.html#index_b"},
 {text:"c",url:"globals.html#index_c"},
+{text:"d",url:"globals.html#index_d"},
 {text:"e",url:"globals.html#index_e"},
+{text:"f",url:"globals.html#index_f"},
+{text:"g",url:"globals.html#index_g"},
+{text:"i",url:"globals.html#index_i"},
+{text:"l",url:"globals.html#index_l"},
+{text:"m",url:"globals.html#index_m"},
+{text:"n",url:"globals.html#index_n"},
 {text:"o",url:"globals.html#index_o"},
 {text:"p",url:"globals.html#index_p"},
+{text:"q",url:"globals.html#index_q"},
+{text:"r",url:"globals.html#index_r"},
+{text:"s",url:"globals.html#index_s"},
+{text:"t",url:"globals.html#index_t"},
 {text:"u",url:"globals.html#index_u"},
-{text:"v",url:"globals.html#index_v"}]},
+{text:"v",url:"globals.html#index_v"},
+{text:"w",url:"globals.html#index_w"}]},
+{text:"Functions",url:"globals_func.html"},
+{text:"Variables",url:"globals_vars.html"},
+{text:"Typedefs",url:"globals_type.html"},
+{text:"Enumerations",url:"globals_enum.html"},
+{text:"Enumerator",url:"globals_eval.html",children:[
+{text:"a",url:"globals_eval.html#index_a"},
+{text:"b",url:"globals_eval.html#index_b"},
+{text:"c",url:"globals_eval.html#index_c"},
+{text:"d",url:"globals_eval.html#index_d"},
+{text:"e",url:"globals_eval.html#index_e"},
+{text:"f",url:"globals_eval.html#index_f"},
+{text:"i",url:"globals_eval.html#index_i"},
+{text:"l",url:"globals_eval.html#index_l"},
+{text:"m",url:"globals_eval.html#index_m"},
+{text:"n",url:"globals_eval.html#index_n"},
+{text:"o",url:"globals_eval.html#index_o"},
+{text:"p",url:"globals_eval.html#index_p"},
+{text:"q",url:"globals_eval.html#index_q"},
+{text:"r",url:"globals_eval.html#index_r"},
+{text:"s",url:"globals_eval.html#index_s"},
+{text:"t",url:"globals_eval.html#index_t"},
+{text:"u",url:"globals_eval.html#index_u"},
+{text:"v",url:"globals_eval.html#index_v"},
+{text:"w",url:"globals_eval.html#index_w"}]},
 {text:"Macros",url:"globals_defs.html",children:[
+{text:"a",url:"globals_defs.html#index_a"},
+{text:"b",url:"globals_defs.html#index_b"},
 {text:"c",url:"globals_defs.html#index_c"},
 {text:"e",url:"globals_defs.html#index_e"},
+{text:"i",url:"globals_defs.html#index_i"},
 {text:"o",url:"globals_defs.html#index_o"},
 {text:"p",url:"globals_defs.html#index_p"},
+{text:"t",url:"globals_defs.html#index_t"},
 {text:"u",url:"globals_defs.html#index_u"},
 {text:"v",url:"globals_defs.html#index_v"}]}]}]}]}
